@@ -1,7 +1,13 @@
 import binascii
 from hashlib import pbkdf2_hmac
+from enum import Enum, auto
 
 
+class AuthErrorStates(Enum):
+    NONE = auto()
+    NotAuthorized = auto()
+    NotRequired = auto()
+
 def hash_password(username, pwd):
     """
     Hashes password using PKDBF2 method:
